## **:- Change Log -:**

> **0.0.1** -- [ 16 JULY 2023 ]  
> [ NOTICE ]  
> [ ! ] - Initial Release

> **0.0.2** -- [ 16 JULY 2023 ]  
> [ FIXED ]  
> [+] Import and Run

> **0.0.3** -- [ 17 JULY 2023 ]  
> [ ADDED ]  
> [+] Package download statistics  
> [+] More Package info

> **0.0.4** -- [ 18 JULY 2023 ]  
> [ FIXED ]  
> [+] windows support

> **0.0.5** -- [ 18 JULY 2023 ]  
> [ FIXED ]  
> [+] temp file furge

> **0.0.6** -- [ 19 JULY 2023 ]  
> [ ADDED ]  
> [+] Amount of package handling.
>
> [ CHANGED ]  
> [+] Interface

> **0.0.7** -- [ 20 JULY 2023 ]  
> [ ADDED ]  
> [+] Previous version
>
> [ FIXED ]  
> [+] Total amount of package downloads
>
> [ CHANGED ]  
> [+] Interface
